==> bugle-0.0.20070718.tar.gz: bugle-0.0.20070718/budgie/bcparser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TYPE_ID = 258,
     ID = 259,
     NUMBER = 260,
     TEXT = 261,
     HEADER = 262,
     LIBRARY = 263,
     LIMIT = 264,
     NEWTYPE = 265,
     BITFIELD = 266,
     EXTRATYPE = 267,
     LENGTH = 268,
     C_STATEMENTS = 269,
     TYPE = 270,
     PARAMETER = 271,
     DUMP = 272,
     BRACKET_PAIR = 273,
     ALIAS = 274
   };
#endif
/* Tokens.  */
#define TYPE_ID 258
#define ID 259
#define NUMBER 260
#define TEXT 261
#define HEADER 262
#define LIBRARY 263
#define LIMIT 264
#define NEWTYPE 265
#define BITFIELD 266
#define EXTRATYPE 267
#define LENGTH 268
#define C_STATEMENTS 269
#define TYPE 270
#define PARAMETER 271
#define DUMP 272
#define BRACKET_PAIR 273
#define ALIAS 274




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 75 "bcparser.yy"
typedef union YYSTYPE {
    std::list<std::string> *str_list;
    std::string *str;
    int num;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 82 "budgie/bcparser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> bugle-0.0.20091026.tar.gz: bugle-0.0.20091026/budgie/bcparser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TYPE_ID = 258,
     ID = 259,
     NUMBER = 260,
     TEXT = 261,
     HEADER = 262,
     LIBRARY = 263,
     LIMIT = 264,
     NEWTYPE = 265,
     BITFIELD = 266,
     EXTRATYPE = 267,
     LENGTH = 268,
     C_STATEMENTS = 269,
     TYPE = 270,
     PARAMETER = 271,
     DUMP = 272,
     BRACKET_PAIR = 273,
     ALIAS = 274,
     CALLAPI = 275
   };
#endif
/* Tokens.  */
#define TYPE_ID 258
#define ID 259
#define NUMBER 260
#define TEXT 261
#define HEADER 262
#define LIBRARY 263
#define LIMIT 264
#define NEWTYPE 265
#define BITFIELD 266
#define EXTRATYPE 267
#define LENGTH 268
#define C_STATEMENTS 269
#define TYPE 270
#define PARAMETER 271
#define DUMP 272
#define BRACKET_PAIR 273
#define ALIAS 274
#define CALLAPI 275




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 76 "bcparser.yy"
{
    std::list<std::string> *str_list;
    std::string *str;
    int num;
}
/* Line 1489 of yacc.c.  */
#line 95 "bcparser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
